homology.dim0.all_roots — GDA Toolbox v1.0 Manual

# homology.dim0.all_roots

`homology.dim0.` `all_roots`()

  Reference each vertex directly to its representative root, from MergeTree.

  This is useful at the end of a MergeTree process, to make sure that components can be looked up quickly.

  Parameters: | components : `numpy.ndarray` The current component look-up table, a NumPy array of `numpy.int64` indices.

#### Previous topic

homology.dim0

#### Next topic

homology.dim0.mkforestDBL